@@ -4,7 +4,8 @@
 #' 
 #' @param network a \code{\link{data.frame}} with variables that describe
 #'        the donor node, the reciever node, the time when each connection between
-#'        donor to the reciever happened and the weight of these connection.
+#'        donor to the reciever happened and the number of individual or weight of
+#'        these connection.
 #' 
 #' @param var.names a \code{\link{list}} with variable names of the network:
 #'        the donor node, the reciever node, the time when each connection between
@@ -52,6 +53,17 @@
 #' @param num.cores  number of  threads/cores that the simulation will use. the
 #'        default value is num.cores = 'max', the algothim will use all
 #'        threads/cores available.
+#' 
+#' @param probWeights a named \code{\link{vector}} (optinal and for migration type
+#'        only) mapping state variables to migration probability weights based on
+#'        state variables. These argument can be used to give weights for sampling
+#'        individuals from node. They need not sum to one, they should be
+#'        non-negative and not zero. For more information on the sampling method
+#'        \link[base]{sample}.
+#'        
+#' @param emigrRule a string (optinal and for migration type only) stating how
+#'        many individual emigrate based on state variables. It requires that the
+#'        network have weights instead of number of individuals that migrate.
 #'
 #' @return Object containing a \code{\link{data.frame}} (results) with the number
 #'         of individuals through time per node and per state.
@@ -138,12 +150,12 @@
 #' # default plot layout (plot.types: 'pop.mean', 'subpop', or 'subpop.mean')
 #' # plot(sim.results, plot.type = 'subpop.mean')
 #'
-hybridModel <-   function(network, var.names = NULL, link.type = 'migration',
-                          model = 'custom', init.cond, fill.time = F,
-                          model.parms, prop.func = NULL, state.var = NULL,
-                          infl.var = NULL, state.change.matrix = NULL,
-                          ssa.method = list(method = "D", epsilon = 0.03,
-                                            nc = 10, dtf = 10, nd = 100),
+hybridModel <-   function(network = stop("undefined 'network'"), var.names = NULL,
+                          link.type = 'migration', model = 'custom', probWeights = NULL,
+                          emigrRule = NULL, init.cond = stop("undefined 'initial conditions'"),
+                          fill.time = F, model.parms = stop("undefined 'model parmeters'"),
+                          prop.func = NULL, state.var = NULL, infl.var = NULL,
+                          state.change.matrix = NULL, ssa.method = NULL,
                           nodesCensus = NULL, sim.number = 1, pop.correc = TRUE,
                           num.cores = 'max'){
   
@@ -176,8 +188,8 @@ hybridModel <-   function(network, var.names = NULL, link.type = 'migration',
                                                    pop.correc = pop.correc,
                                                    nodes.info = nodesCensus),
                                               class = c(model1, 'HM')), var.names,
-                                    init.cond, model.parms, prop.func, state.var,
-                                    infl.var, state.change.matrix)
+                                    init.cond, model.parms, probWeights, emigrRule,
+                                    prop.func, state.var, infl.var, state.change.matrix)
                                     
                             
   #### running the simulation ####
